#include "sinVisualizer.h"

//--------------------------------------------------------------
void SinVisualizer::setup(){
	ofSetVerticalSync(true);
	ofSetWindowShape(WIDTH, HEIGHT);
	
	ofSetCircleResolution(100);
	
	ofBackground(255, 255, 255);
	theta = M_PI/2;
	theta_vel = 0;
}

//--------------------------------------------------------------
void SinVisualizer::update(){

}

//--------------------------------------------------------------
void SinVisualizer::draw(){

	
	int trail_start_x = 3*ROTATION_RADIUS;
	
	float x = 1.5 * ROTATION_RADIUS;
	float y = ofGetHeight()/2;
	
	ofNoFill();
	ofSetColor(0, 0, 0, 127);
	ofCircle(x, y, ROTATION_RADIUS);
	
	
	float cycle = 1.0f / SECONDS_PER_CYCLE;
	
	
	
	switch (CYCLE_MODE) {
		case CIRCLE:
		default:
			// SIMPLE OSCILLATION
			theta = ofGetElapsedTimef() * 2 * M_PI * cycle;
			break;
	
		case PENDULUM:
			// PENDULUM OSCILLATION
			theta_vel += (1.0f * 1.0f / ROTATION_RADIUS) * sin(theta);
			theta += theta_vel;
			break;
	}
	
	
	x = x + sin(theta) * ROTATION_RADIUS;
	y = y + -cos(theta) * ROTATION_RADIUS;
	
	
	ofFill();
	ofSetColor(0, 0, 0, 255);
	ofSetRectMode(OF_RECTMODE_CENTER);
	ofRect(x, y, SQUARE_WIDTH, SQUARE_WIDTH);
	
	
	// now push to the vector
	points.insert(points.begin(), ofPoint(x,y));

	int max_points = HISTORY_SECONDS * ofGetFrameRate();
	while(points.size() > max_points) {
		points.pop_back();
	}

	// now draw the points
	int counter = 0;
	float x_per_point = (ofGetWidth() - trail_start_x) / max_points;
	
	vector<ofPoint>::const_iterator it = points.begin();
	
	ofNoFill();
	ofBeginShape();
	// we are doing a reverse index on the vector
	for(it; it!=points.end(); ++it) {

		x = trail_start_x + counter * x_per_point;
		y = it->y;

		ofVertex(x, y);
		std::cout << "did x " << x << " y " << y << std::endl;
		++counter;
	}
	ofVertex(x, y);
	ofEndShape(false);

}

//--------------------------------------------------------------
void SinVisualizer::keyPressed(int key){

}

//--------------------------------------------------------------
void SinVisualizer::keyReleased(int key){

}

//--------------------------------------------------------------
void SinVisualizer::mouseMoved(int x, int y ){

}

//--------------------------------------------------------------
void SinVisualizer::mouseDragged(int x, int y, int button){

}

//--------------------------------------------------------------
void SinVisualizer::mousePressed(int x, int y, int button){

}

//--------------------------------------------------------------
void SinVisualizer::mouseReleased(int x, int y, int button){

}

//--------------------------------------------------------------
void SinVisualizer::windowResized(int w, int h){

}

